@@ -1,14 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2010-2011 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2010-2015 -- leonerd@leonerd.org.uk
 
 package ExtUtils::CChecker;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use Carp;
 
@@ -81,6 +81,11 @@ If given, sets the C<quiet> option to the underlying C<ExtUtils::CBuilder>
 instance. If absent, defaults to enabled. To disable quietness, i.e. to print
 more verbosely, pass a defined-but-false value, such as C<0>.
 
+=item config => HASH
+
+If given, passed through as the configuration of the underlying
+C<ExtUtils::CBuilder> instance.
+
 =back
 
 =cut
@@ -93,7 +98,10 @@ sub new
    my $quiet = 1;
    $quiet = 0 if defined $args{quiet} and !$args{quiet};
 
-   my $cb = ExtUtils::CBuilder->new( quiet => $quiet );
+   my $cb = ExtUtils::CBuilder->new(
+      quiet  => $quiet,
+      config => $args{config},
+   );
 
    return bless {
       cb  => $cb,
